<?php

/**
 * Glossary
 *
 * @package   Glossary
 * @author    Codeat <support@codeat.co>
 * @copyright 2016 GPL 2.0
 * @license   GPL-2.0
 * @link      http://codeat.co
 */

/**
 * Last glossary terms widget
 */
class Last_Glossary_Widget extends WPH_Widget {

	/**
	 * Initialize the widget
	 *
	 * @return void
	 */
	public function __construct() {
		$args = array(
            'label'       => __( 'Glossary Latest Terms', 'glossary-by-codeat' ),
            'description' => __( 'List of latest Glossary Terms', 'glossary-by-codeat' ),
        );

        $args[ 'fields' ] = array(
            array(
                'name'     => __( 'Title', 'glossary-by-codeat' ),
                'desc'     => __( 'Enter the widget title.', 'glossary-by-codeat' ),
                'id'       => 'title',
                'type'     => 'text',
                'class'    => 'widefat',
                'std'      => __( 'Latest Glossary Terms', 'glossary-by-codeat' ),
                'validate' => 'alpha_dash',
                'filter'   => 'strip_tags|esc_attr',
            ),
            array(
                'name'     => __( 'Number', 'glossary-by-codeat' ),
                'desc'     => __( 'The number of terms to be shown.', 'glossary-by-codeat' ),
                'id'       => 'number',
                'type'     => 'text',
                'validate' => 'numeric',
                'std'      => 5,
                'filter'   => 'strip_tags|esc_attr',
            ),
            array(
                'name'     => __( 'Category', 'glossary-by-codeat' ),
                'desc'     => __( 'Filter from Glossary category.', 'glossary-by-codeat' ),
                'id'       => 'tax',
                'type'     => 'taxonomyterm',
                'taxonomy' => 'glossary-cat',
            ),
        );

        $this->create_widget( $args );
    }

    /**
     * Print the widget
     *
     * @param array $args     Parameters.
     * @param array $instance Values.
     *
     * @return void
     */
    public function widget( $args, $instance ) {
        $out  = $args[ 'before_widget' ];
        $out .= $args[ 'before_title' ];
        if ( !isset( $instance[ 'tax' ] ) ) {
            $instance[ 'tax' ] = array();
        }

        $out .= $instance[ 'title' ];
        $out .= $args[ 'after_title' ];
        $out .= '<div class="widget-glossary-terms-list">';
		$out .= get_glossary_terms_list( 'last', $instance[ 'number' ], $instance[ 'tax' ] );
		$out .= '</div>';
		$out .= $args[ 'after_widget' ];
		echo $out; // phpcs:ignore
	}

}

// Register widget
if ( !function_exists( 'glossary_last_register_widget' ) ) {

	/**
	 * Last item
	 *
	 * @return void
	 */
	function glossary_last_register_widget() {
		register_widget( 'Last_Glossary_Widget' );
	}

	add_action( 'widgets_init', 'glossary_last_register_widget', 1 );
}
